==> nifi-minifi-cpp-0.99.1-source.tar.gz: nifi-minifi-cpp-0.99.1-source/extensions/azure/processors/AzureDataLakeStorageFileProcessorBase.cpp <==
/**
 * @file AzureDataLakeStorageFileProcessorBase.cpp
 * AzureDataLakeStorageFileProcessorBase class implementation
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "AzureDataLakeStorageFileProcessorBase.h"

#include "utils/ProcessorConfigUtils.h"
#include "controllerservices/AzureStorageCredentialsService.h"

namespace org::apache::nifi::minifi::azure::processors {

bool AzureDataLakeStorageFileProcessorBase::setFileOperationCommonParameters(
    storage::AzureDataLakeStorageFileOperationParameters& params, core::ProcessContext& context, const core::FlowFile& flow_file) {
  if (!setCommonParameters(params, context, &flow_file)) {
    return false;
  }

  context.getProperty(FileName, params.filename, &flow_file);
  if (params.filename.empty() && (!flow_file.getAttribute("filename", params.filename) || params.filename.empty())) {
    logger_->log_error("No File Name is set and default object key 'filename' attribute could not be found!");
    return false;
  }

  return true;
}

}  // namespace org::apache::nifi::minifi::azure::processors

==> nifi-minifi-cpp-0.99.2-source.tar.gz: nifi-minifi-cpp-0.99.2-source/extensions/azure/processors/AzureDataLakeStorageFileProcessorBase.cpp <==
/**
 * @file AzureDataLakeStorageFileProcessorBase.cpp
 * AzureDataLakeStorageFileProcessorBase class implementation
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "AzureDataLakeStorageFileProcessorBase.h"

#include "utils/ProcessorConfigUtils.h"
#include "controllerservices/AzureStorageCredentialsService.h"

namespace org::apache::nifi::minifi::azure::processors {

bool AzureDataLakeStorageFileProcessorBase::setFileOperationCommonParameters(
    storage::AzureDataLakeStorageFileOperationParameters& params, core::ProcessContext& context, const core::FlowFile& flow_file) {
  if (!setCommonParameters(params, context, &flow_file)) {
    return false;
  }

  params.filename = context.getProperty(FileName, &flow_file).value_or("");
  if (params.filename.empty() && (!flow_file.getAttribute("filename", params.filename) || params.filename.empty())) {
    logger_->log_error("No File Name is set and default object key 'filename' attribute could not be found!");
    return false;
  }

  return true;
}

}  // namespace org::apache::nifi::minifi::azure::processors
